EXPORTS
	??1CBioTestUtils@@UAE@XZ @ 1 NONAME ; CBioTestUtils::~CBioTestUtils(void)
	?CreateBIOEntryFromFileL@CBioTestUtils@@QAEJABVTDesC16@@W4TBIOMessageType@@@Z @ 2 NONAME ; long CBioTestUtils::CreateBIOEntryFromFileL(class TDesC16 const &, enum TBIOMessageType)
	?CreateBIOEntryL@CBioTestUtils@@QAEJAAVTDesC16@@W4TBIOMessageType@@@Z @ 3 NONAME ; long CBioTestUtils::CreateBIOEntryL(class TDesC16 &, enum TBIOMessageType)
	?CreateBioServerMtmRegL@CBioTestUtils@@QAEXXZ @ 4 NONAME ; void CBioTestUtils::CreateBioServerMtmRegL(void)
	?CreateParserL@CBioTestUtils@@QAEPAVCBaseScriptParser2@@J@Z @ 5 NONAME ; class CBaseScriptParser2 * CBioTestUtils::CreateParserL(long)
	?CreateParserTypeL@CBioTestUtils@@QAEPAVCBaseScriptParser2@@J@Z @ 6 NONAME ; class CBaseScriptParser2 * CBioTestUtils::CreateParserTypeL(long)
	?DoAppendVariantName@CBioTestUtils@@SAXAAVTDes16@@@Z @ 7 NONAME ; void CBioTestUtils::DoAppendVariantName(class TDes16 &)
	?EmptyInboxMessagesL@CBioTestUtils@@QAEXXZ @ 8 NONAME ; void CBioTestUtils::EmptyInboxMessagesL(void)
	?GenerateMessagesL@CBioTestUtils@@QAEPAVCMsvEntrySelection@@ABVTDesC16@@H@Z @ 9 NONAME ; class CMsvEntrySelection * CBioTestUtils::GenerateMessagesL(class TDesC16 const &, int)
	?GenerateMessagesL@CBioTestUtils@@QAEPAVCMsvEntrySelection@@XZ @ 10 NONAME ; class CMsvEntrySelection * CBioTestUtils::GenerateMessagesL(void)
	?LogCurrentMessageTypeL@CBioTestUtils@@QAEXJ@Z @ 11 NONAME ; void CBioTestUtils::LogCurrentMessageTypeL(long)
	?LogExtractedFieldsL@CBioTestUtils@@QAEXJ@Z @ 12 NONAME ; void CBioTestUtils::LogExtractedFieldsL(long)
	?MessageBodyL@CBioTestUtils@@QAE?AVTPtrC16@@J@Z @ 13 NONAME ; class TPtrC16 CBioTestUtils::MessageBodyL(long)
	?NewL@CBioTestUtils@@SAPAV1@AAVRTest@@@Z @ 14 NONAME ; class CBioTestUtils * CBioTestUtils::NewL(class RTest &)
	?NewL@CBioTestUtils@@SAPAV1@AAVRTest@@H@Z @ 15 NONAME ; class CBioTestUtils * CBioTestUtils::NewL(class RTest &, int)
	?NewLC@CBioTestUtils@@SAPAV1@AAVRTest@@@Z @ 16 NONAME ; class CBioTestUtils * CBioTestUtils::NewLC(class RTest &)
	?NewLC@CBioTestUtils@@SAPAV1@AAVRTest@@H@Z @ 17 NONAME ; class CBioTestUtils * CBioTestUtils::NewLC(class RTest &, int)
	?ParsedFieldArray@CBioTestUtils@@QAEAAV?$CArrayPtrSeg@VCParsedField@@@@XZ @ 18 NONAME ; class CArrayPtrSeg<class CParsedField> & CBioTestUtils::ParsedFieldArray(void)
	?Reset@CBioTestUtils@@UAEXXZ @ 19 NONAME ; void CBioTestUtils::Reset(void)
	?SetBIOServiceIdL@CBioTestUtils@@QAEJXZ @ 20 NONAME ; long CBioTestUtils::SetBIOServiceIdL(void)
	?SetMessageType@CBioTestUtils@@QAE?AW4TBIOMessageType@@ABVTDesC16@@@Z @ 21 NONAME ; enum TBIOMessageType CBioTestUtils::SetMessageType(class TDesC16 const &)
	?SetSessionPath@CBioTestUtils@@QAEXABVTDesC16@@@Z @ 22 NONAME ; void CBioTestUtils::SetSessionPath(class TDesC16 const &)

